#
#
#    blocked.py
#
#    Python utility to monitor blocked call list.
#
#    Copyright (C) 2023 by Matt Roberts.
#    License: GNU GPL3 (www.gnu.org)
#
#

import sys
import os
import os.path
import io

def get_blocked_age(path):
	if not os.path.exists(path):
		return 0
	return os.path.getmtime(path)

def get_blocked_calls(path):
	if not os.path.exists(path):
		return None
	calls = [ ]
	with io.open(path, 'r') as f:
		while True:
			l = f.readline()
			if not l:
				break
			l = l.strip()
			if not l:
				continue
			l = l.split('#', 1)
			if len(l[0]):
				l = l[0].strip()
				if l:
					calls.append(l)
	return calls


#
#  unit tests
#
if __name__ == '__main__':
	# the test file
	fn = '~/.local/share/WSJT-X/BLOCKED.TXT'
	fn = os.path.expanduser(fn)

	# the test
	sys.stdout.write("Calls in BLOCKED.TXT:\n")
	calls = get_blocked_calls(fn)
	for i in calls:
		sys.stdout.write("+ %s\n" % i)
	sys.stdout.write("%d total\n" % len(calls))
	sys.stdout.write("BLOCKED.TXT mtime = %d\n" % get_blocked_age(fn))

# EOF
